@@ -8,7 +8,8 @@ output <- matrix(1:4,
 htmlTable(output)
 
 ## ------------------------------------------------------------------------
-htmlTable(output,  ctable=c("solid", "double"),
+htmlTable(output,  
+          ctable=c("solid", "double"),
           caption="A table caption above")
 
 ## ------------------------------------------------------------------------
